SES Conda: A simple concept of SES Conda language.

Update log:

1.1.2 2024/10/2 Fixed some of the export() functions. Added a "rels" index in the database() function for relashionship storage.

1.1.1 2024/10/2 Added a function(rels.parse()) for parsing relashionships.

1.0.3 2024/10/2 Fixed the database.load_from_json() function. No need to convert anymore.
